@@ -6,13 +6,15 @@ Information describing the project.
 
 # The package name, which is also the "UNIX name" for the project.
 package = 'oktaauthpy3'
-project = "Okta CLI authentication"
+project = "Okta CLI authentication with Python3 support"
 project_no_spaces = project.replace(' ', '')
-version = '0.2'
+version = '0.5'
 description = 'Authenticates from the CLI'
 authors = ['Peter Gillard-Moss']
 authors_string = ', '.join(authors)
-emails = ['pgillard@thoughtworks.com']
+maintainers = ['Mansab Uppal']
+maintainers_string = ', '.join(maintainers)
+emails = ['muppal@thoughtworks.com']
 license = 'Apache 2.0'
 copyright = '2015 Thoughtworks Inc'
 url = 'https://www.thoughtworks.com/'
